@@ -88,24 +88,11 @@ class Network:
         )
 
     @classmethod
-    def testnet(cls, node='k8s'):
-        nodes = ['sentry0', 'sentry1', 'k8s']
-        if node not in nodes:
-            raise ValueError('Must be one of {}'.format(nodes))
-
-        if node == 'k8s':
-            lcd_endpoint='https://k8s.testnet.lcd.injective.network'
-            grpc_endpoint='k8s.testnet.chain.grpc.injective.network:443'
-            grpc_exchange_endpoint='k8s.testnet.exchange.grpc.injective.network:443'
-        else:
-            lcd_endpoint='https://testnet.lcd.injective.dev'
-            grpc_endpoint=f'{node}.injective.dev:9900'
-            grpc_exchange_endpoint=f'{node}.injective.dev:9910'
-
+    def testnet(cls):
         return cls(
-            lcd_endpoint=lcd_endpoint,
-            grpc_endpoint=grpc_endpoint,
-            grpc_exchange_endpoint=grpc_exchange_endpoint,
+            lcd_endpoint='https://k8s.testnet.lcd.injective.network',
+            grpc_endpoint='k8s.testnet.chain.grpc.injective.network:443',
+            grpc_exchange_endpoint='k8s.testnet.exchange.grpc.injective.network:443',
             chain_id='injective-888',
             fee_denom='inj',
             env='testnet'
@@ -119,8 +106,7 @@ class Network:
             'sentry0',  # us, prod
             'sentry1',  # us, prod
             'sentry2',  # us, staging
-            'sentry3',  # tokyo, prod,
-            'sentry.cd' # dedicated github-runner
+            'sentry3',  # tokyo, prod
         ]
         if node not in nodes:
             raise ValueError('Must be one of {}'.format(nodes))
@@ -149,7 +135,7 @@ class Network:
             lcd_endpoint='http://localhost:10337',
             grpc_endpoint='localhost:9900',
             grpc_exchange_endpoint='localhost:9910',
-            chain_id='injective-1',
+            chain_id='injective-777',
             fee_denom='inj',
             env='local'
         )
